@@ -1,7 +1,7 @@
 """Utilizario de funciones usadas en los procesos de robotizacion
    con Python."""
 
-__version__ = "1.29"
+__version__ = "1.30"
 __author__ = "Jonathan Bolo"
 
 from ctypes.wintypes import PUINT
@@ -788,8 +788,8 @@ def sqlcmd(file_sql:StrOrPath,
                         ' -o ' + str(file_sql_log)       +
                         ' -S ' + credentials['hostname'] +
                         ' -d ' + credentials['database'] + 
-                        ' -U ' + credentials['username'] +
-                        ' -P ' + credentials['password'] +
+                        ' -U \'' + credentials['username'] + '\'' +
+                        ' -P \'' + credentials['password'] + '\'' +
                         ' -f ' + coding )
     
     log.debug("Ejecutando sql")
@@ -862,8 +862,8 @@ def bcp(table,
            ' -e ' + str(file_sql_log)       +
            ' -S ' + credentials['hostname'] +
            ' -d ' + credentials['database'] + 
-           ' -U ' + credentials['username'] +
-           ' -P ' + credentials['password'] +
+           ' -U \'' + credentials['username'] + '\'' +
+           ' -P \'' + credentials['password'] + '\'' +
            ' -c ' + coding +
            ' -b1000 -m1000 -t"|"' )
     
